AccountMeta class

Represents an account's address and metadata about its mutability and whether it must be a signer of the transaction.

Constructors

AccountMeta({required Address address, required AccountRole role})
Creates an AccountMeta with the given address and role.
const

Properties

address Address
The base58-encoded address of the account.
final
hashCode int
The hash code for this object.
no setteroverride
role AccountRole
The role of the account in the transaction.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override