BlockhashLifetimeConstraint class

A constraint which, when applied to a transaction message, makes that transaction message eligible to land on the network. The transaction message will continue to be eligible to land until the network considers the blockhash to be expired.

Inheritance
Annotations
  • @immutable

Constructors

BlockhashLifetimeConstraint({required String blockhash, required BigInt lastValidBlockHeight})
Creates a BlockhashLifetimeConstraint with the given blockhash and lastValidBlockHeight.
const

Properties

blockhash String
A recent blockhash observed by the transaction proposer.
final
hashCode int
The hash code for this object.
no setteroverride
lastValidBlockHeight BigInt
The block height beyond which the network will consider the blockhash to be too old.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override