CancellationTokenSource class

A source that owns a CancellationToken and can cancel it.

Constructors

CancellationTokenSource()
Creates a new source with a fresh CancellationToken.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token CancellationToken
The token associated with this source.
final

Methods

cancel([Object? reason]) → void
Cancels the token with an optional reason.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited