EpochInfo class

Information about the current epoch.

Constructors

EpochInfo({required BigInt absoluteSlot, required BigInt blockHeight})
Creates an EpochInfo.
const

Properties

absoluteSlot BigInt
The current slot.
final
blockHeight BigInt
The current block height.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited