JsonParsedTokenAccount class

The info payload for a parsed token account.

Constructors

JsonParsedTokenAccount({required bool isNative, required Address mint, required Address owner, required TokenAccountState state, required TokenAmount tokenAmount, Address? closeAuthority, Address? delegate, TokenAmount? delegatedAmount, List<Object?>? extensions, TokenAmount? rentExemptReserve})
Creates a new JsonParsedTokenAccount.
const

Properties

closeAuthority Address?
The optional close authority address.
final
delegate Address?
The optional delegate address.
final
delegatedAmount TokenAmount?
The amount delegated, if any.
final
extensions List<Object?>?
The list of token extensions, if any.
final
hashCode int
The hash code for this object.
no setteroverride
isNative bool
Whether this is a native SOL token account.
final
mint Address
The mint address for this token account.
final
owner Address
The owner address of this token account.
final
rentExemptReserve TokenAmount?
The rent-exempt reserve amount, if applicable.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state TokenAccountState
The state of the token account.
final
tokenAmount TokenAmount
The token balance.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override