MemcmpFilterBase58 class

A memory comparison filter for account data, using base58 encoding.

Constructors

MemcmpFilterBase58({required Base58EncodedBytes bytes, required BigInt offset})
Creates a base58-encoded memory comparison filter.
const

Properties

bytes Base58EncodedBytes
The bytes to match, as a base-58 encoded string.
final
encoding String
The encoding used for the byte string.
no setter
hashCode int
The hash code for this object.
no setteroverride
offset BigInt
The byte offset into the account data from which to start the comparison.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override