ResourceLimitsEstimate class

An estimate of the resource limits for a transaction message.

Constructors

ResourceLimitsEstimate({required int computeUnitLimit, int? loadedAccountsDataSizeLimit})
Creates a new ResourceLimitsEstimate.
const

Properties

computeUnitLimit int
The estimated compute unit limit.
final
hashCode int
The hash code for this object.
no setterinherited
loadedAccountsDataSizeLimit int?
The estimated loaded accounts data size limit, if available.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited