SignedLamports typedef

SignedLamports = BigInt

Represents a signed quantity of lamports that can be negative.

This is used in contexts where a balance change can be either positive or negative, such as reward amounts.

Implementation

typedef SignedLamports = BigInt;