TransactionMessageInput class

A minimal representation of a transaction message containing instructions indexed by their position.

This is used by isProgramError to look up the instruction at a given index and determine its program address.

Constructors

TransactionMessageInput({required Map<int, InstructionInput> instructions})
Creates a TransactionMessageInput with the given instructions map.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
instructions Map<int, InstructionInput>
A map of instruction indices to their corresponding InstructionInput.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited