TransactionPlanResult class sealed

The result of executing a transaction plan.

This is structured as a recursive tree of results that mirrors the structure of the original transaction plan.

Properties

hashCode int
The hash code for this object.
no setterinherited
kind String
The kind discriminator for this transaction plan result.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited