UnixTimestamp extension type

Represents a Unix timestamp in seconds.

It is represented as a BigInt in client code and an i64 in server code.

on
Implemented types

Constructors

UnixTimestamp(BigInt value)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value BigInt
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited