eqBinaryFixedPoint function
Returns whether a and b represent the same binary fixed-point value.
Implementation
bool eqBinaryFixedPoint(BinaryFixedPoint a, BinaryFixedPoint b) {
return cmpBinaryFixedPoint(a, b) == 0;
}
Returns whether a and b represent the same binary fixed-point value.
bool eqBinaryFixedPoint(BinaryFixedPoint a, BinaryFixedPoint b) {
return cmpBinaryFixedPoint(a, b) == 0;
}