lteDecimalFixedPoint function
Returns whether a is less than or equal to b.
Implementation
bool lteDecimalFixedPoint(DecimalFixedPoint a, DecimalFixedPoint b) {
return cmpDecimalFixedPoint(a, b) <= 0;
}
Returns whether a is less than or equal to b.
bool lteDecimalFixedPoint(DecimalFixedPoint a, DecimalFixedPoint b) {
return cmpDecimalFixedPoint(a, b) <= 0;
}