subtractDecimalFixedPoint function
Subtracts b from a, requiring both values to have the same shape.
Implementation
DecimalFixedPoint subtractDecimalFixedPoint(
DecimalFixedPoint a,
DecimalFixedPoint b,
) {
return a - b;
}
Subtracts b from a, requiring both values to have the same shape.
DecimalFixedPoint subtractDecimalFixedPoint(
DecimalFixedPoint a,
DecimalFixedPoint b,
) {
return a - b;
}