sysvarClockSize top-level constant
int
const sysvarClockSize
The size in bytes of the Clock sysvar account data.
Implementation
const int sysvarClockSize = 40;
The size in bytes of the Clock sysvar account data.
const int sysvarClockSize = 40;