CanceledSingleTransactionPlanResult class
A canceled SingleTransactionPlanResult.
- Inheritance
-
- Object
- TransactionPlanResult
- SingleTransactionPlanResult
- CanceledSingleTransactionPlanResult
Constructors
-
CanceledSingleTransactionPlanResult({required TransactionMessage plannedMessage, required Map<
String, Object?> context}) -
Creates a CanceledSingleTransactionPlanResult.
const
Properties
-
context
→ Map<
String, Object?> -
Context data associated with this result.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → String
-
The kind discriminator for this transaction plan result.
no setterinherited
- plannedMessage → TransactionMessage
-
The original transaction message from the plan.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → TransactionPlanResultStatus
-
The execution status of this transaction.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited