Represents a client that provides a default identity signer.
The identity is the signer whose assets the application is acting upon. In many applications the identity and payer are the same signer, but the roles can differ when a service pays fees on behalf of a user.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- identity → TSigner
-
The default identity signer.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited