DurableNonceLifetimeConstraint class
A constraint which, when applied to a transaction message, makes that transaction message eligible to land on the network. The transaction message will continue to be eligible to land until the nonce value changes.
- Inheritance
-
- Object
- LifetimeConstraint
- DurableNonceLifetimeConstraint
- Annotations
-
- @immutable
Constructors
- DurableNonceLifetimeConstraint({required String nonce})
-
Creates a DurableNonceLifetimeConstraint with the given
nonce.const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override