SysvarSlotHistory class
A bitvector of slots present over the last epoch.
- Annotations
-
- @immutable
Constructors
-
SysvarSlotHistory({required List<
BigInt> bits, required BigInt nextSlot}) -
Creates a new SysvarSlotHistory.
const
Properties
-
bits
→ List<
BigInt> -
A vector of 64-bit numbers which, when their bits are strung together,
represent a record of non-skipped slots.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- nextSlot → BigInt
-
The number of the slot one newer than tracked by the bitvector.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override