TransactionPlanResult class sealed
The result of executing a transaction plan.
This is structured as a recursive tree of results that mirrors the structure of the original transaction plan.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited